### Data Matrix

The **Data Matrix** symbology is 2D matrix-style barcode that can encode full 256 character extended-ASCII.

Also known as: Data Matrix ECC 200.

Variants:

  * [GS1 DataMatrix](GS1-DataMatrix) is a variant of Data Matrix that should be used when encoding data that is in [GS1 Application Identifier standard format](GS1-Application-Identifier-Standard-Format).
  * [HIBC Data Matrix](HIBC-Symbols) is a variant of Data Matrix that should be used when encoding HIBC formatted data.

Standards: ISO/IEC 16022, ANSI/AIM BC11 - ISS Data Matrix.


#### Data and Options

  * The data field can contain any extended ASCII data. The default interpretation of data by readers is in accordance with ISO/IEC 8859-1.
  * When the **parse** option is specified, any instances of `^NNN` in the data field are replaced with their equivalent ASCII value. This is useful for specifying unprintable characters.
  * When the **parsefnc** option is specified, non-data function characters can be specified by `^FNC1`, `^PROG`, `^MAC5`, `^MAC6`.
  * The **format** option is used to specify the shape of the symbol, either `square` (default) or `rectangle`. 
  * The **dmre** option enable Data Matrix Rectangular Extension with increases the number of rectangular symbol sizes available.
  * The **columns** and **rows** options are used to specify the size of the symbol.
  * The **version** option can also be used to specify the symbol size, as `version=RxC`. Valid options are:
    * With `format=square`: _10x10_, _12x12_, _14x14_, _16x16_, _18x18_, _20x20_, _22x22_, _24x24_, _26x26_, _32x32_, _36x36_, _40x40_, _44x44_, _48x48_, _52x52_, _64x64_, _72x72_, _80x80_, _88x88_, _96x96_, _104x104_, _120x120_, _132x132_, _144x144_
    * With `format=rectangle`: _8x18_, _8x32_, _12x26_, _12x36_, _16x36_, _16x48_
    * With `format=rectangle` and `dmre`: _8x18_, _8x32_, _8x48_, _8x64_, _12x26_, _12x36_, _12x64_, _16x36_, _16x48_, _16x64_, _24x32_, _24x36_, _24x48_, _24x64_, _26x32_, _26x40_, _26x48_, _26x64_
  * If **columns**, **rows** and **version** are unspecified the encoder will default to creating a symbol of the specified **format** that is the minimum size to represent the given data.


#### Examples

```
Data:    This is Data Matrix
Options: 
Encoder: datamatrix
```

```
Data:    This is ^068ata Matrix
Options: parse
Encoder: datamatrix
```

![](images/datamatrix-1.png)

```
Data:    Fixed size
Options: rows=48 columns=48
Encoder: datamatrix
```

![](images/datamatrix-2.png)

```
Data:    Rectangular
Options: format=rectangle version=16x48
Encoder: datamatrix
```

![](images/datamatrix-3.png)
