## GS1 Composite Symbols

**GS1 Composite** barcode symbologies consist of a primary component beneath a 2D component (variations of [MicroPDF417](MicroPDF417) and [PDF417](PDF417)) used to encode supplementary [GS1 formatted data](GS1-Application-Identifier-Standard-Format).

Variants:

  * [EAN-13 Composite](#ean-13-composite) is a variant of [EAN-13](EAN-13).
  * [EAN-8 Composite](#ean-8-composite) is a variant of [EAN-8](EAN-8).
  * [UPC-A Composite](#upc-a-composite) is a variant of [UPC-A](UPC-A).
  * [UPC-E Composite](#upc-e-composite) is a variant of [UPC-E](UPC-E).
  * [GS1 DataBar Omnidirectional Composite](#gs1-databar-omnidirectional-composite) is a variant of [GS1 DataBar Omnidirectional](GS1-DataBar-Omnidirectional).
  * [GS1 DataBar Stacked Omnidirectional Composite](#gs1-databar-stacked-omnidirectional-composite) is a variant of [GS1 DataBar Stacked Omnidirectional](GS1-DataBar-Stacked-Omnidirectional).
  * [GS1 DataBar Expanded Composite](#gs1-databar-expanded-composite) is a variant of [GS1 DataBar Expanded](GS1-DataBar-Expanded).
  * [GS1 DataBar Expanded Stacked Composite](#gs1-databar-expanded-stacked-composite) is a variant of [GS1 DataBar Expanded Stacked](GS1-DataBar-Expanded-Stacked).
  * [GS1 DataBar Truncated Composite](#gs1-databar-truncated-composite) is a variant of [GS1 DataBar Truncated](GS1-DataBar-Truncated).
  * [GS1 DataBar Stacked Composite](#gs1-databar-stacked-composite) is a variant of [GS1 DataBar Stacked](GS1-DataBar-Stacked).
  * [GS1 DataBar Limited Composite](#gs1-databar-limited-composite) is a variant of [GS1 DataBar Limited](GS1-DataBar-Limited).
  * [GS1-128 Composite](#gs1-128-composite) is a variant of [GS1-128](GS1-128).

Standards: ISO/IEC 24723, ITS EAN.UCC Composite Symbology, AIM ISS - EAN.UCC Composite Symbology, GS1 General Specifications.

#### Data and Options

  * The data field consists of a primary and secondary component separated by a pipe `|` character.
  * The data for the primary component (preceding the pipe) is entered in a format identical to the corresponding non-composite barcode symbology.
  * The data for the 2D component (following the pipe) is entered in [GS1 Application Identifier standard format](GS1-Application-Identifier-Standard-Format).
  * For maximum efficiency, if the data for the 2D component contains a number of application identifiers matching any of the specifications below then they should be provided in this given order:
    * `(11)...(10)...`
    * `(17)...(10)...`
    * `(90){0-3 digits not starting 0}{upper alpha}...`
  * The **ccversion** option is used to select a specific 2D component:
    * `ccversion=a` - [CC-A](#cc-a)
    * `ccversion=b` - [CC-B](#cc-b)
    * `ccversion=c` - [CC-C](#cc-c) ([GS1-128 Composite](#gs1-128-composite) only)
  * If **ccversion** is not specified a CC-A component will be selected if the data will fit, otherwise a CC-B component will be used. In the case of [GS1-128 Composite](#gs1-128-composite) a CC-C component will be used if the data does not fit within either a CC-A or CC-B component.

### EAN-13 Composite

```
Data:    331234567890|(99)1234-abcd
Options: includetext guardwhitespace
Encoder: ean13composite
```

![](images/ean13composite-1.png)

### EAN-8 Composite

```
Data:    12345670|(21)A12345678
Options: includetext guardwhitespace
Encoder: ean8composite
```

![](images/ean8composite-1.png)

### UPC-A Composite

```
Data:    01600033610|(99)1234-abcd
Options: includetext
Encoder: upcacomposite
```

![](images/upcacomposite-1.png)

### UPC-E Composite

```
Data:    0121230|(15)021231
Options: includetext
Encoder: upcecomposite
```

![](images/upcecomposite-1.png)

### GS1 DataBar Omnidirectional Composite

```
Data:    (01)03612345678904|(11)990102
Options: 
Encoder: databaromnicomposite
```

![](images/databaromnicomposite-1.png)

### GS1 DataBar Stacked Omnidirectional Composite

```
Data:    (01)03612345678904|(11)990102
Options: 
Encoder: databarstackedomnicomposite
```

![](images/databarstackedomnicomposite-1.png)

### GS1 DataBar Expanded Composite

```
Data:    (01)93712345678904(3103)001234|(91)1A2B3C4D5E
Options: 
Encoder: databarexpandedcomposite
```

![](images/databarexpandedcomposite-1.png)

### GS1 DataBar Expanded Stacked Composite

```
Data:    (01)00012345678905(10)ABCDEF|(21)12345678
Options: segments=4
Encoder: databarexpandedstackedcomposite
```

![](images/databarexpandedstackedcomposite-1.png)

### GS1 DataBar Truncated Composite

```
Data:    (01)03612345678904|(11)990102
Options: 
Encoder: databartruncatedcomposite
```

![](images/databartruncatedcomposite-1.png)

### GS1 DataBar Stacked Composite

```
Data:    (01)03412345678900|(17)010200
Options: 
Encoder: databarstackedcomposite
```

![](images/databarstackedcomposite-1.png)

### GS1 DataBar Limited Composite

```
Data:    (01)03512345678907|(21)abcdefghijklmnopqrstuv
Options: 
Encoder: databarlimitedcomposite
```

![](images/databarlimitedcomposite-1.png)

### GS1-128 Composite

GS1-128 Composite with a CC-A 2D component:

```
Data:    (01)03212345678906|(21)A1B2C3D4E5F6G7H8
Options: 
Encoder: gs1-128composite
```

![](images/ean128composite-1.png)

GS1-128 Composite with a CC-C 2D component:

```
Data:    (00)030123456789012340|(02)13012345678909(37)24(10)1234567ABCDEFG
Options: ccversion=c
Encoder: gs1-128composite
```

![](images/ean128composite-2.png)

### CC-A

Isolated CC-A 2D component:

```
Data:    (01)95012345678903
Options: ccversion=a cccolumns=3
Encoder: gs1-cc
```

![](images/gs1composite-1.png)

### CC-B

Isolated CC-B 2D component:

```
Data:    (01)95012345678903(3103)000123
Options: ccversion=b cccolumns=4
Encoder: gs1-cc
```

![](images/gs1composite-2.png)

### CC-C

Isolated CC-C 2D component:

```
Data:    (02)13012345678909(37)24(10)1234567ABCDEFG
Options: ccversion=c cccolumns=5
Encoder: gs1-cc
```

![](images/gs1composite-3.png)
