### ISBN

An **ISBN** barcode is a variant of [EAN-13](EAN-13) that is used to identify books.

Also known as: ISBN-13, International Standard Book Number, Bookland EAN-13.

Variants:

* ISBN-10 is a legacy format that was depreciated for public use after 1st January 2007.

Standards: ISO 2108, ISO/IEC 15420, BS EN 797, GS1 General Specifications.

#### Data and Options

  * The data should contain twelve or thirteen digits separated appropriately by dash characters _-_.
  * The data can also be provided in legacy ISBN-10 format as nine or ten digits separated appropriately by dash characters _-_. This will be automatically upgraded to the ISBN-13 format.
  * If the last digit of the primary data is not given then the ISBN check digit is calculated automatically.
  * The **legacy** option prevents ISBN-10 input from being upgraded to ISBN-13 and will result in a symbol that is obsolete and should not be used at point of sale.
  * The primary data can optionally be followed by a space then two or five digits if an [EAN-2](EAN-2) or [EAN-5](EAN-5) add-on is required.
  * The **includetext** option should normally be supplied.
  * The **guardwhitespace** option enables the display of white space guard marks.
  * The following options are also relevant to this barcode symbology:
    * **isbntextfont**: Font name for text above symbol
    * **isbntextsize**: Font size for the text above symbol, in points
    * **isbntextxoffset**: Horizontal position of ISBN text, in points
    * **isbntextyoffset**: Vertical position of ISBN text, in points

#### Example ISBN

Identical symbols, input provided with and without an ISBN check digit:

```
Data:    978-1-873671-00-9
Options: includetext
Encoder: isbn
```

```
Data:    978-1-873671-00
Options: includetext
Encoder: isbn
```

![](images/isbn-1.png)

An ISBN with a [five-digit add-on](EAN-5):

```
Data:    978-1-873671-00-9 54499
Options: includetext guardwhitespace
Encoder: isbn
```

![](images/isbn-2.png)

The following ISBN-10 input will be automatically upgraded to a valid ISBN-13 symbol:

```
Data:    1-86074-271-2
Options: includetext
Encoder: isbn
```

```
Data:    1-86074-271
Options: includetext
Encoder: isbn
```

![](images/isbn-3.png)

#### Example ISBN-10 

Note that ISBN-10 is legacy format not for use at P.O.S.

The following will generate an obsolete ISBN-10 symbol:

```
Data:    1-86074-271-8
Options: legacy includetext guardwhitespace
Encoder: isbn
```

```
Data:    1-86074-271
Options: legacy includetext guardwhitespace
Encoder: isbn
```

![](images/isbn-4.png)

