### ISMN

An **ISMN** barcode is a variant of [EAN-13](EAN-13) with a prefix _979_ that is used to identify printed music.

Also known as: International Standard Music Number, ISMN-13.

Variants:

* ISMN-10 is a legacy format that was depreciated for public use.

Standards: ISO 10957, ISO/IEC 15420, BS EN 797, GS1 General Specifications.

#### Data and Options

  * The data should contain twelve or thirteen digits separated appropriately by dash characters _-_.
  * The data can also be provided in legacy ISMN-10 format start _M-_ then eight or nine digits separated appropriately by dash characters _-_. This will be automatically upgraded to the ISMN-13 format.
  * The **legacy** option prevents ISMN-10 input from being upgraded to ISMN-13 and will result in a symbol that is obsolete and should not be used at point of sale.
  * If the last digit of the primary data is not given then the ISMN check digit is calculated automatically.
  * The primary data can optionally be followed by a space then two or five digits if an [EAN-2](EAN-2) or [EAN-5](EAN-5) add-on is required.
  * The **includetext** option should normally be supplied.
  * The **guardwhitespace** option enables the display of white space guard marks.
  * The following options are also relevant to this barcode symbology:
    * **ismntextfont**: Font name for text above symbol
    * **ismntextsize**: Font size for the text above symbol, in points
    * **ismntextxoffset**: Horizontal position of ISMN text, in points
    * **ismntextyoffset**: Vertical position of ISMN text, in points

#### Example ISMN

Identical symbols, input provided with and without an ISMN check digit:

```
Data:    979-0-2600-0043-8
Options: includetext
Encoder: ismn
```

```
Data:    979-0-2600-0043
Options: includetext
Encoder: ismn
```

![](images/ismn-1.png)

The following ISMN-10 input will be automatically upgraded to a valid ISMN-13 symbol:

```
Data:    M-345-24680-5
Options: includetext
Encoder: ismn
```

```
Data:    M-345-24680
Options: includetext
Encoder: ismn
```

![](images/ismn-2.png)

#### Example ISMN-10

Note that ISMN-10 is a legacy format not for use at P.O.S.

The following will generate an obsolete ISMN-10 symbol:

```
Data:    M-345-24680-5
Options: legacy includetext guardwhitespace
Encoder: ismn
```

```
Data:    M-345-24680
Options: legacy includetext guardwhitespace
Encoder: ismn
```

![](images/ismn-3.png)

